## host definition file - where you specify the physical configuration for all of your various host types
## role: the type of 'thing' it is, currently used options are controller, compute, storage, and container.
## macs: python list of all the macs belonging to this type of host
## interface: the interface that you want to use when PXE booting (should be DHCP enabled)
## proxy: if you have a static, external proxy, place the address here.  Otherwise use pull_from_mine to use the internal one
## root_password: preseeded password.  See mkpasswd.
## ntp_server: the ntp server that you want to use for the preseed process
## disk:  the disk you want to install the OS on to
## ipmi_addresses: the addresses for the IPMI interfaces on these devices

## kvm_disk_config - CONTROLLER ONLY
## type: raidX, where X is 1 or 10.  raid1 must have 2 members entries in the list.  raid10 must have a multiple of 2 members in the list
## type: standard.  May pass a device (e.g. /dev/sdb) as a single member, or pass the special value 'rootfs' as a single member, which will
## just create a directory on the root filesystem at /kvm

## networks: specify how you want your final, post-deployment network to be configured.
##   interface entries: top level definition will be the name of the physical interface
##     managed: whether or not the builtin networking state should manage the configuration.  boolean, defaults to True
##     interfaces: list of interfaces that will bind to the network.  If the list is <1, it implies a bond.
##     bridge: true if a bridged interface, otherwise false or omitted (implicit false)

hosts:
  controllerv1:
    style: physical
    role: controller
    enabled: False
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-3CECEF4A6F00
      - 00000000-0000-0000-0000-3CECEF4A724C
      - 00000000-0000-0000-0000-3CECEF4A723C
      - 00000000-0000-0000-0000-3CECEF4A7228
      - 00000000-0000-0000-0000-3CECEF4A7224
    interface: enp129s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: SAMSUNG MZWLL6T4HMLA
    kvm_disk_config:
      type: standard
      members:
        - rootfs
    networks:
      management:
        interfaces: [enp129s0f0]
        bridge: true
      sfe:
        interfaces: [enp161s0f0]
        bridge: true
      public:
        interfaces: [enp129s0f1]
        bridge: true
      private:
        interfaces: [enp161s0f1]
        bridge: true
  storagev1:
    style: physical
    role: storage
    enabled: True
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-0CC47A22AD20
      - 00000000-0000-0000-0000-0CC47A22AD94
      - 00000000-0000-0000-0000-0CC47A22AD48
      - 00000000-0000-0000-0000-0CC47A22AD90
      - 00000000-0000-0000-0000-0CC47A22AD38
      - 00000000-0000-0000-0000-0CC47A22AD98
      - 00000000-0000-0000-0000-0CC47A22AD30
#      - 00000000-0000-0000-0000-0CC47A22AD4C
      - 00000000-0000-0000-0000-0CC47A22AD44
    interface: ens5f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDSC2BA40
    networks:
      management:
        interfaces: [ens5f0]
      sfe:
        interfaces: [ens7f0np0, ens7f1np1]
      sbe:
        interfaces: [ens5f1, ens5f2, ens5f3]
  computev1:
    style: physical
    role: compute
    enabled: True
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-3CECEF4A645C
      - 00000000-0000-0000-0000-3CECEF4A6350
      - 00000000-0000-0000-0000-3CECEF4A6438
      - 00000000-0000-0000-0000-3CECEF4A21EC
      - 00000000-0000-0000-0000-3CECEF4A6324
      - 00000000-0000-0000-0000-3CECEF4A2290
      - 00000000-0000-0000-0000-3CECEF4A211C
    interface: enp129s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDPE2KX010T8
    networks:
      management:
        interfaces: [enp129s0f0]
      sfe:
        interfaces: [enp161s0f0]
      public:
        interfaces: [enp129s0f1]
      private:
        interfaces: [enp161s0f1]
    initial_cpu_allocation_ratio: 3.2
    initial_ram_allocation_ratio: 1.5
  computev2:
    style: physical
    role: compute
    enabled: True
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-3CECEF4A21FC
      - 00000000-0000-0000-0000-3CECEF4A6450
      - 00000000-0000-0000-0000-3CECEF4A641C
      - 00000000-0000-0000-0000-3CECEF4A6424
      - 00000000-0000-0000-0000-3CECEF4A6444
      - 00000000-0000-0000-0000-3CECEF4A6460
      - 00000000-0000-0000-0000-3CECEF4A643C
    interface: enp129s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDPE2KX010T8
    networks:
      management:
        interfaces: [enp129s0f0]
      sfe:
        interfaces: [enp161s0f0]
      public:
        interfaces: [enp129s0f1]
      private:
        interfaces: [enp161s0f1]
    initial_cpu_allocation_ratio: 1.6
    initial_ram_allocation_ratio: 1.5
  containerv1:
    style: physical
    role: container
    enabled: False
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-0CC47AF98E18
    interface: ens2f0np0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDSC2BA40
    networks:
      management:
        interfaces: [ens2f0np0]
      sfe:
        interfaces: [ens2f1np1]
      public:
        interfaces: [ens2f3np3]
      private:
        interfaces: [ens2f2np2]
  gpu:
    style: physical
    role: gpu
    enabled: True
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-3CECEF4A3000
      - 00000000-0000-0000-0000-3CECEF117506
      - 00000000-0000-0000-0000-3CECEF4A3AF8
      - 00000000-0000-0000-0000-3CECEF11D80A
      - 00000000-0000-0000-0000-3CECEF4A3AF4
    interface: enp193s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDPE2KX010T8
    networks:
      management:
        interfaces: [enp193s0f0]
      sfe:
        interfaces: [enp161s0f0]
      public:
        interfaces: [enp193s0f1]
      private:
        interfaces: [enp161s0f1]
    initial_cpu_allocation_ratio: 1.6
    initial_ram_allocation_ratio: 1.5
  cache:
    style: virtual
    enabled: False
    count: 1
    ram: 8192000
    cpu: 2
    os: ubuntu2004
    disk: 512G
    networks:
      management:
        interfaces: [ens3]
  cephmon:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  mds:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  haproxy:
    style: virtual
    enabled: False
    count: 1
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  antora:
    style: virtual
    enabled: False
    count: 1
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 16G
    networks:
      management:
        interfaces: [ens3]
  mysql:
    style: virtual
    enabled: True
    count: 3
    ram: 16384000
    cpu: 8
    os: ubuntu2004
    disk: 128G
    networks:
      management:
        interfaces: [ens3]
  rabbitmq:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  memcached:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  keystone:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  glance:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  nova:
    style: virtual
    enabled: True
    count: 5
    ram: 16384000
    cpu: 8
    os: ubuntu2004
    disk: 128G
    networks:
      management:
        interfaces: [ens3]
  neutron:
    style: virtual
    enabled: True
    count: 5
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  horizon:
    style: virtual
    enabled: True
    count: 4
    ram: 8192000
    cpu: 8
    os: ubuntu2004
    disk: 128G
    networks:
      management:
        interfaces: [ens3]
  heat:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  cinder:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  volume:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  designate:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  bind:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  swift:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  zun:
    style: virtual
    enabled: True
    count: 2
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  placement:
    style: virtual
    enabled: True
    count: 5
    ram: 8192000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  graylog:
    style: virtual
    enabled: False
    count: 1
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 512G
    networks:
      management:
        interfaces: [ens3]
  network:
    style: virtual
    enabled: False
    count: 5
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
      private:
        interfaces: [ens4]
      public:
        interfaces: [ens5]
  ovsdb:
    style: virtual
    enabled: False
    count: 1
    ram: 16384000
    cpu: 8
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  barbican:
    style: virtual
    enabled: True
    count: 2
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  magnum:
    style: virtual
    enabled: True
    count: 2
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  sahara:
    style: virtual
    enabled: True
    count: 2
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  manila:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  share:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  etcd:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  guacamole:
    style: virtual
    enabled: False
    count: 1
    ram: 8192000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  webssh2:
    style: virtual
    enabled: False
    count: 1
    ram: 8192000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]